#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Tue Feb  9 20:56:31 2021

@author: anton
"""
from SLiCAP import *

# Initialize a project
prj = initProject('Active antenna')

# Create the html page with the application description
htmlPage('Application description')
img2html('activeAntennaAssignment.svg', 600)
file2html('applicationDescription.txt')
head2html('Where to start')
text2html('First we need to understand the application.')
file2html('understandTheApplication.txt')

# Calculate and display the antenna chatacteristics
fileName = 'antenna'

# Generate the netlist from the LTspice schematic file:
#makeNetlist(fileName + '.asc', 'Antenna circuit')

# Define an instruction:
i1 = instruction()

# Check the circuit and assign the circuit opject to the i1.circuit attribute:
i1.setCircuit(fileName + '.cir')

# Create an html page for displaying the circuit data:
htmlPage('Circuit data')

# Create a H2 header of the page:
head2html('Circuit diagram of the antenna')

# Display the circuit diagram on the page:
img2html(fileName + '.svg', 400, label='schematics', caption = 'Equivalent lumped elements circuit for the antenna.')

# Display the netlist on the page;
# This comes with its own h2 header:
netlist2html(fileName + '.cir', label = 'netlist')

# Display the circuit element data on the html page;
# This comes with its own h2 header:
elementData2html(i1.circuit, label='elementData', caption = 'Data of the elements of the lumped element antenna model')

# Display the circuit parameters on the html page
# This comes with its own h2 header:
params2html(i1.circuit, label = 'cirParams', caption = 'Parameters of the lumped element antenna model')

# Create a page for displaying the antenna impedance (data and Bode plots)
htmlPage('Antenna impedance')
head2html('Zero frequency capacitance')
C_a = sp.Symbol('C_a')
C_A = i1.getParValue('C_A')
text2html('The zero-frequency antenna capacitance equals:')
eqn2html(C_a, C_A, units='F', label='CA', labelText = 'Antenna capacitance')
# Plot the impedance characteristic
head2html('Bode plots')
i1.setSimType('numeric')
i1.setGainType('gain')
i1.setDataType('laplace')
i1.setSource('I1')
i1.setDetector('V_1')
result = i1.execute()
figMag = plotSweep('mag', 'Magnitude of the antenna impedance', result, 0.001, 1e3, 500, sweepScale='M', funcType = 'mag', yUnits='$\\Omega$', yScale = 'k', show = True)
figPhase = plotSweep('phase', 'Phase of the antenna impedance', result, 0.001, 1e3, 500, sweepScale='M', funcType = 'phase', show = True)

# Put some text on the page:
text2html('The figures below show the magnitude and the phase characteristic of the antenna impedance.')
fig2html(figMag, 600, label='mag', caption='Magnitude characteristic of the antenna impedance')
fig2html(figPhase, 600, label='phase', caption='Phase characteristic of the antenna impedance')